@@ -11,7 +11,6 @@ for which a new license (GPL+exception) is in place.
 
 #include "constraintsdialog.h"
 #include "database.h"
-#include "sqleditor.h"
 
 
 ConstraintsDialog::ConstraintsDialog(const QString & tabName, const QString & schema, QWidget * parent)
@@ -26,9 +25,6 @@ ConstraintsDialog::ConstraintsDialog(const QString & tabName, const QString & sc
 	ui.insertName->setText(QString("tr_cons_%1_ins").arg(tabName));
 	ui.updateName->setText(QString("tr_cons_%1_upd").arg(tabName));
 	ui.deleteName->setText(QString("tr_cons_%1_del").arg(tabName));
-	new SqlEditorTools::SqlHighlighter(ui.insertEdit->document());
-	new SqlEditorTools::SqlHighlighter(ui.updateEdit->document());
-	new SqlEditorTools::SqlHighlighter(ui.deleteEdit->document());
 
 	// not nulls
 	QStringList inserts;
@@ -55,7 +51,7 @@ ConstraintsDialog::ConstraintsDialog(const QString & tabName, const QString & sc
 	if(query.lastError().isValid())
 	{
 		ui.resultEdit->setText(tr("Error while parsing constraints: %1.\n\n%2")
-				.arg(query.lastError().databaseText())
+				.arg(query.lastError().text())
 				.arg(sql));
 		return;
 	}
@@ -114,40 +110,40 @@ void ConstraintsDialog::createButton_clicked()
 
 	QString status("INSERT trigger\n");
 	createTrigger("begin transaction;");
-	if (ui.insertEdit->toPlainText().length() != 0)
+	if (ui.insertEdit->text().length() != 0)
 	{
 		status += createTrigger(templ.arg(ui.insertName->text())
 								.arg("INSERT")
 								.arg(m_schema)
 								.arg(m_table)
 								.arg("-- created by Sqliteman tool")
-								.arg(ui.insertEdit->toPlainText()));
+								.arg(ui.insertEdit->text()));
 	}
 	else
 		status += tr("No action for INSERT");
 
 	status += "\nUPDATE trigger\n";
-	if (ui.updateEdit->toPlainText().length() != 0)
+	if (ui.updateEdit->text().length() != 0)
 	{
 		status += createTrigger(templ.arg(ui.updateName->text())
 								.arg("UPDATE")
 								.arg(m_schema)
 								.arg(m_table)
 								.arg("-- created by Sqliteman tool")
-								.arg(ui.updateEdit->toPlainText()));
+								.arg(ui.updateEdit->text()));
 	}
 	else
 		status += tr("No action for UPDATE");
 
 	status += "\nDELETE trigger\n";
-	if (ui.deleteEdit->toPlainText().length() != 0)
+	if (ui.deleteEdit->text().length() != 0)
 	{
 		status += createTrigger(templ.arg(ui.deleteName->text())
 								.arg("DELETE")
 								.arg(m_schema)
 								.arg(m_table)
 								.arg("-- created by Sqliteman tool")
-								.arg(ui.deleteEdit->toPlainText()));
+								.arg(ui.deleteEdit->text()));
 	}
 	else
 		status += tr("No action for DELETE");
@@ -160,7 +156,7 @@ QString ConstraintsDialog::createTrigger(const QString & sql)
 	QString ret;
 	QSqlQuery query(sql, QSqlDatabase::database(SESSION_NAME));
 	if(query.lastError().isValid())
-		return tr("Error while creating trigger: %1.").arg(query.lastError().databaseText());
+		return tr("Error while creating trigger: %1.").arg(query.lastError().text());
 	update = true;
 	return tr("Trigger created successfully");
 }
