@@ -25,7 +25,7 @@ bool Database::execSql(QString statement)
 	QSqlQuery query(statement, QSqlDatabase::database(SESSION_NAME));
 	if(query.lastError().isValid())
 	{
-		exception(tr("Error executing: %1.").arg(query.lastError().databaseText()));
+		exception(tr("Error executing: %1.").arg(query.lastError().text()));
 		return false;
 	}
 	return true;
@@ -43,7 +43,7 @@ DbAttach Database::getDatabases()
 
 	if (query.lastError().isValid())
 	{
-		exception(tr("Cannot get databases list. %1").arg(query.lastError().databaseText()));
+		exception(tr("Cannot get databases list. %1").arg(query.lastError().text()));
 		return ret;
 	}
 	while(query.next())
@@ -58,7 +58,7 @@ bool Database::dropTable(const QString & table, const QString & schema)
 	
 	if(query.lastError().isValid())
 	{
-		exception(tr("Error while dropping table %1: %2.").arg(table).arg(query.lastError().databaseText()));
+		exception(tr("Error while dropping table %1: %2.").arg(table).arg(query.lastError().text()));
 		return false;
 	}
 	return true;
@@ -71,7 +71,7 @@ FieldList Database::tableFields(const QString & table, const QString & schema)
 	QSqlQuery query(sql, QSqlDatabase::database(SESSION_NAME));
 	if (query.lastError().isValid())
 	{
-		exception(tr("Error while getting the fileds of %1: %2.").arg(table).arg(query.lastError().databaseText()));
+		exception(tr("Error while getting the fileds of %1: %2.").arg(table).arg(query.lastError().text()));
 		return fields;
 	}
 
@@ -81,6 +81,8 @@ FieldList Database::tableFields(const QString & table, const QString & schema)
 		field.cid = query.value(0).toInt();
 		field.name = query.value(1).toString();
 		field.type = query.value(2).toString();
+		if (field.type.isNull() || field.type.isEmpty())
+			field.type = "NULL";
 		field.notnull = query.value(3).toBool();
 		field.defval = query.value(4).toString();
 		field.pk = query.value(5).toBool();
@@ -91,18 +93,40 @@ FieldList Database::tableFields(const QString & table, const QString & schema)
 	return fields;
 }
 
+QStringList Database::indexFields(const QString & index, const QString &schema)
+{
+	QString sql(QString("PRAGMA \"%1\".INDEX_INFO(\"%2\");").arg(schema).arg(index));
+	QSqlQuery query(sql, QSqlDatabase::database(SESSION_NAME));
+	QStringList fields;
+
+	if (query.lastError().isValid())
+	{
+		exception(tr("Error while getting the fileds of %1: %2.").arg(index).arg(query.lastError().text()));
+		return fields;
+	}
+
+	while (query.next())
+		fields.append(query.value(2).toString());
+
+	return fields;
+}
+
 DbObjects Database::getObjects(const QString type, const QString schema)
 {
 	DbObjects objs;
 
-	QSqlQuery query(QString("SELECT name, tbl_name FROM \"%1\".sqlite_master WHERE type = '%2' and name not like 'sqlite_%';").arg(schema).arg(type),
-					QSqlDatabase::database(SESSION_NAME));
+	QString sql;
+	if (type.isNull())
+		sql = QString("SELECT lower(name), lower(tbl_name) FROM \"%1\".sqlite_master;").arg(schema);
+	else
+		sql = QString("SELECT lower(name), lower(tbl_name) FROM \"%1\".sqlite_master WHERE type = '%2' and name not like 'sqlite_%';").arg(schema).arg(type);
 
+	QSqlQuery query(sql, QSqlDatabase::database(SESSION_NAME));
 	while(query.next())
 		objs.insertMulti(query.value(1).toString(), query.value(0).toString());
 
 	if(query.lastError().isValid())
-		exception(tr("Error while the list of %1: %2.").arg(type).arg(query.lastError().databaseText()));
+		exception(tr("Error while the list of %1: %2.").arg(type).arg(query.lastError().text()));
 
 	return objs;
 }
@@ -124,7 +148,7 @@ QStringList Database::getSysIndexes(const QString & table, const QString & schem
 	}
 
 	if(query.lastError().isValid())
-		exception(tr("Error while the list of the system catalogue: %2.").arg(query.lastError().databaseText()));
+		exception(tr("Error while the list of the system catalogue: %2.").arg(query.lastError().text()));
 
 	return sysIx;
 }
@@ -133,7 +157,7 @@ DbObjects Database::getSysObjects(const QString & schema)
 {
 	DbObjects objs;
 
-	QSqlQuery query(QString("SELECT name, tbl_name FROM \"%1\".sqlite_master WHERE type = 'table' and name like 'sqlite_%';").arg(schema),
+	QSqlQuery query(QString("SELECT lower(name), lower(tbl_name) FROM \"%1\".sqlite_master WHERE type = 'table' and name like 'sqlite_%';").arg(schema),
 					QSqlDatabase::database(SESSION_NAME));
 
 	objs.insert("sqlite_master", "");
@@ -141,7 +165,7 @@ DbObjects Database::getSysObjects(const QString & schema)
 		objs.insertMulti(query.value(1).toString(), query.value(0).toString());
 
 	if(query.lastError().isValid())
-		exception(tr("Error while the list of the system catalogue: %2.").arg(query.lastError().databaseText()));
+		exception(tr("Error while the list of the system catalogue: %2.").arg(query.lastError().text()));
 
 	return objs;
 }
@@ -153,7 +177,7 @@ bool Database::dropView(const QString & view, const QString & schema)
 	
 	if(query.lastError().isValid())
 	{
-		exception(tr("Error while dropping the view %1: %2.").arg(view).arg(query.lastError().databaseText()));
+		exception(tr("Error while dropping the view %1: %2.").arg(view).arg(query.lastError().text()));
 		return false;
 	}
 	return true;
@@ -166,7 +190,7 @@ bool Database::dropIndex(const QString & name, const QString & schema)
 	
 	if(query.lastError().isValid())
 	{
-		exception(tr("Error while dropping the index %1: %2.").arg(name).arg(query.lastError().databaseText()));
+		exception(tr("Error while dropping the index %1: %2.").arg(name).arg(query.lastError().text()));
 		return false;
 	}
 	return true;
@@ -201,6 +225,24 @@ bool Database::exportSql(const QString & fileName)
 	return true;
 }
 
+QString Database::describeObject(const QString & name,
+								 const QString & schema)
+{
+	QString sql("select sql from \"%1\".sqlite_master where lower(name) = \"%2\";");
+	QSqlQuery query(sql.arg(schema).arg(name), QSqlDatabase::database(SESSION_NAME));
+	
+	if (query.lastError().isValid())
+	{
+		exception(tr("Error while describe object %1: %2.").arg(name).arg(query.lastError().text()));
+		return "";
+	}
+	
+	while(query.next())
+		return query.value(0).toString();
+	
+	return "";
+}
+
 bool Database::dropTrigger(const QString & name, const QString & schema)
 {
 	QString sql = QString("DROP TRIGGER \"%1\".\"%2\";").arg(schema).arg(name);
@@ -208,7 +250,7 @@ bool Database::dropTrigger(const QString & name, const QString & schema)
 	
 	if(query.lastError().isValid())
 	{
-		exception(tr("Error while dropping the trigger %1: %2.").arg(name).arg(query.lastError().databaseText()));
+		exception(tr("Error while dropping the trigger %1: %2.").arg(name).arg(query.lastError().text()));
 		return false;
 	}
 	return true;
@@ -228,3 +270,19 @@ QString Database::hex(const QByteArray & val)
 	}
 	return ret + "'";
 }
+
+QString Database::pragma(const QString & name)
+{
+	QString statement("PRAGMA main.%1;");
+	QSqlQuery query(statement.arg(name), QSqlDatabase::database(SESSION_NAME));
+	if (query.lastError().isValid())
+	{
+		exception(tr("Error executing: %1.").arg(query.lastError().text()));
+		return "error";
+	}
+
+	while(query.next())
+		return query.value(0).toString();
+	return tr("Not Set");
+}
+
