@@ -63,10 +63,11 @@ class Database
 		static DbAttach getDatabases();
 		/*! \brief Gather user objects from sqlite_master by type.
 		It skips the resrved names "sqlite_%". See getSysObjects().
-		\param type a "enum" 'table', 'view', index etc.
+		\param type a "enum" 'table', 'view', index etc. If it's empty all objects are selected.
+		\param schema a name of the DB schema
 		\retval DbObjects a map with "object name"/"its parent"
 		*/
-		static DbObjects getObjects(const QString type, const QString schema = "main");
+		static DbObjects getObjects(const QString type = 0, const QString schema = "main");
 
 		/*! \brief Gather "SYS schema" objects.
 		\param schema a string with "attached db" name
@@ -104,23 +105,26 @@ class Database
 
 		/*!
 		@brief Drop a trigger from the database
-		@param table The name of the trigger to drop
+		\param name The name of the trigger to drop
 		\param schema a table own schema
 		\retval bool true on success, false on error. Error are reported in this method
 		             already. */
 		static bool dropTrigger(const QString & name, const QString & schema);
 
 		/*!
-		* @brief Returns the list of fields in a table
-		*
-		* @param table The table to retrive the fields from
-		* @return The list of fields in \a table
+		@brief Returns the list of fields in a table
+		@param table The table to retrive the fields from
+		\param schema a name of the DB schema
+		@return The list of fields in \a table
 		*/
 		static FieldList tableFields(const QString & table, const QString & schema);
 		
+		//! \brief Returns the list of columns in given index
+		static QStringList indexFields(const QString & index, const QString &schema);
+		
 		/*!
 		@brief Drop a view from the database
-		@param table The name of the view to drop
+		\param view The name of the view to drop
 		\param schema a table own schema
 		\retval bool true on success, false on error. Error are reported in this method
 		             already. */
@@ -128,7 +132,7 @@ class Database
 
 		/*!
 		@brief Drop an index from the database
-		@param table The name of the index to drop
+		\param name The name of the index to drop
 		\param schema a table own schema
 		\retval bool true on success, false on error. Error are reported in this method
 		             already. */
@@ -142,12 +146,20 @@ class Database
 		*/
 		static bool exportSql(const QString & fileName);
 
+		static QString describeObject(const QString & name, const QString & schema = "main");
+
 		/*! \brief BLOB X'foo' notation. See sqlite3 internals as a reference.
 		\param val a raw "encoded" QByteArray (string)
 		\retval QString with sqlite encoded X'blah' notation.
 		*/
 		static QString hex(const QByteArray & val);
 
+		/*! \brief Query the DB for its specified PRAGMA setting.
+		\param name a pragma name (PRAGMA name;)
+		\retval QString pragma value or "n/a" string if it is not set at all.
+		*/
+		static QString pragma(const QString & name);
+
 	private:
 		//! \brief Error feedback to the user.
 		static void exception(const QString & message);
